EVOlutionary algorithms toolbox for VAriational Quantum circuits (EVOVAQ) is a novel evolutionary framework designed
to easily train variational quantum circuits through evolutionary techniques, and to have a simple interface between
these algorithms and quantum libraries, such as Qiskit.

**Optimizers in EVOVAQ:**

* Genetic Algorithm

* Differential Evolution

* Memetic Algorithm

* Big Bang Big Crunch

* Particle Swarm Optimization

* CHC Algorithm

* Hill Climbing